Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(379)

Unified Diff: webrtc/modules/audio_coding/neteq/timestamp_scaler_unittest.cc

Issue 2685783014: Replace NULL with nullptr in all C++ files. (Closed)
Patch Set: Fixing android. Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webrtc/modules/audio_coding/neteq/timestamp_scaler_unittest.cc
diff --git a/webrtc/modules/audio_coding/neteq/timestamp_scaler_unittest.cc b/webrtc/modules/audio_coding/neteq/timestamp_scaler_unittest.cc
index 13c45547aeaeef28ed32964453069dd736b67c3c..75b63bdedcc8759af770cc9685a3657e35e2f950 100644
--- a/webrtc/modules/audio_coding/neteq/timestamp_scaler_unittest.cc
+++ b/webrtc/modules/audio_coding/neteq/timestamp_scaler_unittest.cc
@@ -300,13 +300,14 @@ TEST(TimestampScaler, Failures) {
static const uint8_t kRtpPayloadType = 17;
MockDecoderDatabase db;
EXPECT_CALL(db, GetDecoderInfo(kRtpPayloadType))
- .WillOnce(ReturnNull()); // Return NULL to indicate unknown payload type.
+ .WillOnce(
+ ReturnNull()); // Return nullptr to indicate unknown payload type.
TimestampScaler scaler(db);
uint32_t timestamp = 4711; // Some number.
EXPECT_EQ(timestamp, scaler.ToInternal(timestamp, kRtpPayloadType));
- Packet* packet = NULL;
+ Packet* packet = nullptr;
scaler.ToInternal(packet); // Should not crash. That's all we can test.
EXPECT_CALL(db, Die()); // Called when database object is deleted.

Powered by Google App Engine
This is Rietveld 408576698